@@ -6,22 +6,18 @@ from koda._generics import A, B
 
 @dataclass(frozen=True)
 class Nothing:
-    def map(self, _: Callable[[Any], Any]) -> "Nothing":
-        """
-        >>> nothing.map(lambda _: 5)
-        Nothing
-        """
+    def get_or_else(self, fallback: A) -> A:
+        return fallback
+
+    def map(self, _: Callable[[Any], B]) -> "Maybe[B]":
         return self
 
-    def flat_map(self, _: Callable[[Any], Any]) -> "Nothing":
+    def flat_map(self, _: Callable[[Any], "Maybe[B]"]) -> "Maybe[B]":
         return self
 
-    def apply(self, _: "Maybe[Callable[[Any], Any]]") -> "Nothing":
+    def apply(self, _: "Maybe[Callable[[Any], B]]") -> "Maybe[B]":
         return self
 
-    def __repr__(self) -> str:
-        return "Nothing"
-
 
 # just a pre-init-ed instance of nothing.
 nothing: Final[Nothing] = Nothing()
@@ -31,7 +27,10 @@ nothing: Final[Nothing] = Nothing()
 class Just(Generic[A]):
     val: A
 
-    def map(self, fn: Callable[[A], B]) -> "Just[B]":
+    def get_or_else(self, _: Any) -> A:
+        return self.val
+
+    def map(self, fn: Callable[[A], B]) -> "Maybe[B]":
         return Just(fn(self.val))
 
     def flat_map(self, fn: Callable[[A], "Maybe[B]"]) -> "Maybe[B]":
