@@ -1,10 +1,9 @@
-from typing import Any, Callable, Mapping, List
+from typing import Any, Callable, List, Mapping, Optional, Protocol, TypeVar
 
 from koda._cruft import _compose, _safe_try
 from koda._generics import A, B, FailT
 from koda.maybe import Just, Maybe, nothing
-from koda.result import Err, Result, Ok
-
+from koda.result import Err, Ok, Result
 
 compose = _compose
 
@@ -29,6 +28,13 @@ def maybe_to_result(fail_message: FailT, orig: Maybe[A]) -> Result[A, FailT]:
         return Err(fail_message)
 
 
+def to_maybe(val: Optional[A]) -> Maybe[A]:
+    if val is None:
+        return nothing
+    else:
+        return Just(val)
+
+
 def result_to_maybe(orig: Result[A, Any]) -> Maybe[A]:
     return Just(orig.val) if isinstance(orig, Ok) else nothing
 
@@ -51,3 +57,18 @@ def load_once(fn: Callable[[], A]) -> Callable[[], A]:
 
 
 safe_try = _safe_try
+
+
+A_co = TypeVar("A_co", covariant=True)
+
+
+class _AnyArgs(Protocol[A_co]):  # pragma: no cover
+    def __call__(self, *args: Any, **kwargs: Any) -> A_co:
+        ...
+
+
+def always(x: A) -> _AnyArgs[A]:
+    def inner(*args: Any, **kwargs: Any) -> A:
+        return x
+
+    return inner
